#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <signal.h>
#include <stdint.h>
#include <stdlib.h>
#include "airstick.h"

int airstick_fd;
int errno;

void airstick_exit() {
	printf("%s\n", "Turning off airstick");
	ioctl(airstick_fd, AIRSTICK_POWER_OFF);
	printf("%s\n", "Exiting");
	exit(0);
}

void airstick_init() {
	airstick_fd = open("/dev/airstick", O_RDWR);
	if(airstick_fd < 0) {
		perror("can't open airstick");
		exit(-1);
	}
	signal(SIGINT, airstick_exit);
	printf("%s\n", "Turning on airstick");
	ioctl(airstick_fd, AIRSTICK_POWER_ON);
}

int main(int argc, char **argv) {
	airstick_raw reading;
	int nsamps = 200;
	uint8_t status;
	
	char status_string[200];
	
	airstick_init();
	
	if(argc == 2) {
		nsamps = atoi(argv[1]);
		if(nsamps > 255) nsamps = 255;
		if(nsamps < 5) nsamps = 5;
	}
	ioctl(airstick_fd, AIRSTICK_SET_NSAMPS, nsamps);
	
	while(1) {
		usleep(50000);
		status = ioctl(airstick_fd, AIRSTICK_GET_STATUS);
		if((status & STATUS_ON) == 0) {
			printf("%s\n", "AirStick off");
			continue;
		} else if((status & STATUS_LEFT) == 0) {
			sprintf(status_string, "%s", "Left board connected");
		} else if((status & STATUS_RIGHT) == 0) {
			sprintf(status_string, "%s", "Right board connected");
		} else {
			printf("%s\n", "No antenna connected");
			continue;
		}
			
		if( read(airstick_fd, &reading, 8) < 8)
			printf("%s\n", "error reading from airstick");
		else
			printf("%d\t%d\t%d\t%d\t%s\n", reading.up, reading.down, reading.left, reading.right, status_string);
	}
	return 0;
}
